@@ -5,11 +5,14 @@
 
 #include <string>
 #include <vector>
+#include <optional>
 
 struct SFinderResult {
-    std::string       label;
-    std::string       icon;
-    SP<IFinderResult> result;
+    std::string                label;
+    std::string                icon;
+    SP<IFinderResult>          result;
+    std::optional<std::string> overrideFont;
+    bool                       hasIcon = false;
 };
 
 constexpr const size_t MAX_RESULTS_PER_FINDER = 15;
