@@ -6,6 +6,7 @@
 #include "../socket/ServerSocket.hpp"
 #include "../helpers/Log.hpp"
 #include "../config/ConfigManager.hpp"
+#include "../i18n/Engine.hpp"
 
 #include <hyprutils/string/String.hpp>
 #include <xkbcommon/xkbcommon-keysyms.h>
@@ -14,9 +15,11 @@ using namespace Hyprutils::Math;
 using namespace Hyprutils::String;
 
 constexpr const size_t MAX_RESULTS_IN_LAUNCHER = 25;
+constexpr const char*  DEFAULT_FONT            = "Sans Serif";
 
 CUI::CUI(bool open) : m_openByDefault(open) {
-    static auto PGRABFOCUS = Hyprlang::CSimpleConfigValue<Hyprlang::INT>(g_configManager->m_config.get(), "general:grab_focus");
+    static auto PGRABFOCUS  = Hyprlang::CSimpleConfigValue<Hyprlang::INT>(g_configManager->m_config.get(), "general:grab_focus");
+    static auto PWINDOWSIZE = Hyprlang::CSimpleConfigValue<Hyprlang::VEC2>(g_configManager->m_config.get(), "ui:window_size");
 
     m_backend = Hyprtoolkit::IBackend::create();
 
@@ -33,7 +36,7 @@ CUI::CUI(bool open) : m_openByDefault(open) {
     m_layout->setMargin(4);
 
     m_inputBox = Hyprtoolkit::CTextboxBuilder::begin()
-                     ->placeholder("Search something...")
+                     ->placeholder(I18n::localize(I18n::TXT_KEY_SEARCH_SOMETHING, {}))
                      ->onTextEdited([](SP<Hyprtoolkit::CTextboxElement>, const std::string& query) { g_queryProcessor->scheduleQueryUpdate(query); })
                      ->size({Hyprtoolkit::CDynamicSize::HT_SIZE_PERCENT, Hyprtoolkit::CDynamicSize::HT_SIZE_ABSOLUTE, {1.F, 28.F}})
                      ->multiline(false)
@@ -67,7 +70,7 @@ CUI::CUI(bool open) : m_openByDefault(open) {
     m_window = Hyprtoolkit::CWindowBuilder::begin()
                    ->appClass("hyprlauncher")
                    ->type(Hyprtoolkit::HT_WINDOW_LAYER)
-                   ->preferredSize({400, 260})
+                   ->preferredSize({(*PWINDOWSIZE).x, (*PWINDOWSIZE).y})
                    ->anchor(1 | 2 | 4 | 8)
                    ->exclusiveZone(-1)
                    ->layer(3)
@@ -128,7 +131,7 @@ void CUI::setWindowOpen(bool open) {
         m_inputBox->rebuild()->defaultText("")->commence();
 
         for (const auto& b : m_resultButtons) {
-            b->setLabel("");
+            b->setLabel("", "", DEFAULT_FONT, false);
             b->setActive(false);
         }
 
@@ -146,7 +149,9 @@ void CUI::setWindowOpen(bool open) {
 }
 
 void CUI::onSelected() {
-    g_serverIPCSocket->sendSelectionMade(m_currentResults.at(m_activeElementId).result->fuzzable());
+    if (m_currentResults.size() <= m_activeElementId)
+        return;
+    g_serverIPCSocket->sendSelectionMade(m_currentResults.at(m_activeElementId).result->name());
     m_currentResults.at(m_activeElementId).result->run();
     setWindowOpen(false);
     g_queryProcessor->overrideQueryProvider(WP<IFinder>{});
@@ -162,7 +167,10 @@ void CUI::updateResults(std::vector<SFinderResult>&& results) {
     m_activeElementId = 0;
 
     for (size_t i = 0; i < m_resultButtons.size(); ++i) {
-        m_resultButtons[i]->setLabel(m_currentResults.size() <= i ? "" : m_currentResults[i].label);
+        if (m_currentResults.size() <= i)
+            m_resultButtons[i]->setLabel("", "", DEFAULT_FONT, false);
+        else
+            m_resultButtons[i]->setLabel(m_currentResults[i].label, m_currentResults[i].icon, m_currentResults[i].overrideFont.value_or(DEFAULT_FONT), m_currentResults[i].hasIcon);
     }
 
     updateActive();
